@@ -23,6 +23,9 @@ We run it on [a very simple imperfect information game called Kuhn poker](kuhn/i
 
 [![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/lab-ml/nn/blob/master/labml_nn/cfr/kuhn/experiment.ipynb)
 
+[![Twitter thread](https://img.shields.io/twitter/url?style=social&url=https%3A%2F%2Ftwitter.com%2Flabmlai%2Fstatus%2F1407186002255380484)](https://twitter.com/labmlai/status/1407186002255380484)
+Twitter thread
+
 ## Introduction
 
 We implement Monte Carlo Counterfactual Regret Minimization (MCCFR) with chance sampling (CS).
@@ -680,19 +683,19 @@ class CFR:
         """
 
         # Loop for `epochs` times
-        for t in monit.loop(self.epochs):
+        for t in monit.iterate('Train', self.epochs):
             # Walk tree and update regrets for each player
             for i in range(self.n_players):
                 self.walk_tree(self.create_new_history(), cast(Player, i), 1, 1)
 
             # Track data for analytics
+            tracker.add_global_step()
             self.tracker(self.info_sets)
             tracker.save()
 
             # Save checkpoints every $1,000$ iterations
             if (t + 1) % 1_000 == 0:
                 experiment.save_checkpoint()
-                tracker.new_line()
 
         # Print the information sets
         logger.inspect(self.info_sets)
@@ -716,15 +719,14 @@ class InfoSetTracker:
         """
         Track the data from all information sets
         """
-        with monit.section("Track"):
-            for I in info_sets.values():
-                avg_strategy = I.get_average_strategy()
-                for a in I.actions():
-                    tracker.add({
-                        f'strategy.{I.key}.{a}': I.strategy[a],
-                        f'average_strategy.{I.key}.{a}': avg_strategy[a],
-                        f'regret.{I.key}.{a}': I.regret[a],
-                    })
+        for I in info_sets.values():
+            avg_strategy = I.get_average_strategy()
+            for a in I.actions():
+                tracker.add({
+                    f'strategy.{I.key}.{a}': I.strategy[a],
+                    f'average_strategy.{I.key}.{a}': avg_strategy[a],
+                    f'regret.{I.key}.{a}': I.regret[a],
+                })
 
 
 class CFRConfigs(BaseConfigs):
